Merge auxiliary variables with data
Value
a data frame containing the contaminant data in wide format, with the auxiliary variables pivoted to match the determinands they are linked to
Details
info$determinand identifies which auxiliary variables are linked to each
determinand; info$auxiliary also allows the user (currently limited) some
control over how the auxiliary variables are linked to the determinand data
Some variables can both be determinands to be assessed and auxiliary variables (for example, CORG or DRYWT%)