Utility function for reading reference tables:
Arguments
- id
Character string identifying the reference table; currently must be one of
"determinand","species","thresholds","matrix","imposex","pivot_values","method_extraction"`.- files
Named list of file paths, with one of the names matching
id- compartment
Character string: must be one of
"biota","sediment"or"water"- file_diagnostics
Logical. The default (
FALSE) is to print out a simple message confirming which file has been read. WhenTRUE, the MD5 digest and full path is also printed.